translate.lang.af

Package translate :: Package lang :: Module af |
[hide private]
[frames] | no frames]

# Module af

source code

This module represents Afrikaans language.

For more information, see http://en.wikipedia.org/wiki/Afrikaans_language

Classes | [hide private]
| af This class represents Afrikaans.

Functions | [hide private]
tranliterate_cyrillic(text) Convert Cyrillic text to Latin according to the AWS transliteration rules. | source code

Variables | [hide private]
| articlere = `re.compile(r'\'n\b')`
| cyr2lat = ``{``u'``Ё``'``:` `'``Jo``'``,` `u'``А``'``:` `'``A``'``,` `u'``Б``'``:` `'``B``'``,` `u'``В``'``:` `'``W``'``,` `u'``Г``'``:` `...`` Mapping of Cyrillic to Latin letters for transliteration in Afrikaans
| cyr_vowels = ``u'``аеёиоуыэюя``'``
| __package__ = ``'``translate.lang``'``

Imports: re, common

Variables Details | [hide private]

  ### cyr2lat Mapping of Cyrillic to Latin letters for transliteration in Afrikaans Value:
      {u'Ё': 'Jo',
       u'А': 'A',
       u'Б': 'B',
       u'В': 'W',
       u'Г': 'G',
       u'Д': 'D',
       u'ДЖ': 'Dj',
       u'Е': 'Je',
      ...